/**
 * @jest-environment jsdom
 */

// Copyright (c) 2023 Tudor Stanciu

import axios from "axios";
import { TuitioClient, fetch } from "../client";

jest.mock("axios");

test("Tuitio client: successfully account logout", async () => {
  (axios.request as jest.Mock).mockResolvedValue({
    data: {
      result: { userId: 0, userName: "tuitio.user", logoutDate: new Date() },
      error: null
    }
  });

  const client = new TuitioClient("https://test.com/api");
  const logoutResult = await client.logout("token-mock");

  expect(logoutResult.result.userId).toBe(0);
  expect(logoutResult.result.userName).toBe("tuitio.user");
  expect(logoutResult.error).toBeNull();

  const storage = fetch();
  expect(storage).toBeDefined();
  expect(storage.token).toBeNull();
  expect(storage.validUntil).toBeNull();
  expect(storage.userName).toBeNull();
});
